# About
*timberas* is a Python package with tools to support research and design of Australian timber structures. It can be used to determine the material properties, section properties, and design capacities for structural members as per Australian Standard AS1720.1:2020 (Timber Structures Part 1: Design Methods). 

# Documentation
Detailed information on *timberas* is available in package documentation at [timberas.readthedocs.io](https://timberas.readthedocs.io/). This includes project background, examples, and an API reference guide.

# Installation
*timberas* can be installed from the Python Package index:
```
pip install timberas
```
For more detailed instructions, please refer to the [documentation]([https://timberas.readthedocs.io]).

# Current Features
- **Section library**: define sections and calculate section properties from typical Australian timber product dimensions, or from custom user input. 
- **Material library**: create timber materials from typical Australian grade classifications (F-Grade, MGP, Glulam), or from custom user input.
- **Design capacity calculations**: solve the design capacities of structural timber members in tension, compression, bending, and shear, following AS1720.1 design methods.

# Questions, Feedback, and Contributions 
If you have questions, feedback, or suggestions for further development, please email [Joe Gattas](https://researchers.uq.edu.au/researcher/9443) or create an issue on the *timberas* github repository.

Similarly, if you find any bugs, or are interested to contribute to the project, please create an issue or email Joe.


# License 
*timberas* is an open source engineering tool provided under an MIT License. Please refer to the [LICENSE](./LICENSE.md) file for more information. 

Please note that this software has been developed by student and academic engineering researchers, NOT by chartered or registered engineers. 

# Acknowledgements
This package has been developed from research projects supported by the [University of Queensland](https://civil.uq.edu.au/), [ARC Future Timber Hub](https://futuretimberhub.org/) (2016-2021), and [ARC Advance Timber Hub](https://www.advance-timber-hub.org/) (2022-).


If you use *timberas* for projects or scientific publications, please consider citing our journal paper:
> Jiang, J., Ottenhaus, L. M., & Gattas, J. M. (2023). A parametric design framework for timber framing span tables. *Australian Journal of Civil Engineering*, 1-16. [doi:10.1080/14488353.2023.2227432](https://doi.org/10.1080/14488353.2023.2227432).

